"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = markRegExp;

var React = _interopRequireWildcard(require("react"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj["default"] = obj; return newObj; } }

function _toArray(arr) { return _arrayWithHoles(arr) || _iterableToArray(arr) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

/**
 * Replaces matching patterns in a string with markers.
 *
 * @param {string} content The content to parse and mark.
 *
 * @param {RegExp} rule The pattern to search and replace in the content.
 *
 * @param {Function} tag A function that takes the match string and must return
 * a React component or a string. The value returned by that function will
 * replace the term in the output.
 *
 * @param {number} matchIndex The index of the match to use when marking with
 * a RegExp. If not provided, will use the last non-null match available.
 *
 * @returns {Array} An array of strings and React components, similar to the
 * original content but where each matching pattern has been replaced by a
 * marking component.
 */
function markRegExp(content, rule, tag, matchIndex) {
  var output = [];
  var remaining = content;
  var matches = rule.exec(remaining);

  while (matches) {
    var match = void 0;

    if (typeof matchIndex !== 'undefined' && matchIndex !== null) {
      match = matches[matchIndex];
    } else {
      // Use the last non-null matching form. This is to support several
      // capture groups in the rule.
      match = matches.reduce(function (acc, cur) {
        return cur || acc;
      }, '');
    }

    var _remaining$split = remaining.split(match),
        _remaining$split2 = _toArray(_remaining$split),
        previous = _remaining$split2[0],
        rest = _remaining$split2.slice(1);

    if (previous) {
      output.push(previous);
    }

    output.push(tag(match)); // Compute the next step.

    remaining = rest.join(match);
    matches = rule.exec(remaining);
  }

  if (remaining) {
    output.push(remaining);
  }

  return output;
}